@@ -60,9 +60,9 @@ class StackComponentFlavor(DictEnum):
     CONTAINER_REGISTRY = "container_registry"
     STEP_OPERATOR = "step_operator"  # TODO
     EXPERIMENT_TRACKER = "experiment_tracker"
-    #FEATURE_STORE = "feature_store"  # TODO
-    #SECRETS_MANAGER = "secrets_manager"  # TODO
-    #MODEL_DEPLOYER = "model_deployer"  # TODO
+    FEATURE_STORE = "feature_store"  # TODO
+    SECRETS_MANAGER = "secrets_manager"  # TODO
+    MODEL_DEPLOYER = "model_deployer"  # TODO
 
 
 class DirectoryStoreFlavor(DictEnum):
